==> zio-aws-apigatewayv2_2.12-6.20.42.1-sources.jar: zio/aws/apigatewayv2/model/GetModelTemplateResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetModelTemplateResponse(
    value: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateResponse = {
    import GetModelTemplateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateResponse
      .builder()
      .optionallyWith(value.map(value => value: java.lang.String))(_.value)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetModelTemplateResponse.ReadOnly =
    zio.aws.apigatewayv2.model.GetModelTemplateResponse.wrap(buildAwsValue())
}
object GetModelTemplateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetModelTemplateResponse =
      zio.aws.apigatewayv2.model
        .GetModelTemplateResponse(value.map(value => value))
    def value: Optional[__string]
    def getValue: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateResponse
  ) extends zio.aws.apigatewayv2.model.GetModelTemplateResponse.ReadOnly {
    override val value: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.value())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateResponse
  ): zio.aws.apigatewayv2.model.GetModelTemplateResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_2.13-5.17.112.1-sources.jar: zio/aws/apigatewayv2/model/GetModelTemplateResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetModelTemplateResponse(value: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateResponse = {
    import GetModelTemplateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateResponse
      .builder()
      .optionallyWith(
        value.map(value => __string.unwrap(value): java.lang.String)
      )(_.value)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetModelTemplateResponse.ReadOnly =
    zio.aws.apigatewayv2.model.GetModelTemplateResponse.wrap(buildAwsValue())
}
object GetModelTemplateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetModelTemplateResponse =
      zio.aws.apigatewayv2.model
        .GetModelTemplateResponse(value.map(value => value))
    def value: Option[__string]
    def getValue: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateResponse
  ) extends zio.aws.apigatewayv2.model.GetModelTemplateResponse.ReadOnly {
    override val value: Option[__string] = scala
      .Option(impl.value())
      .map(value => zio.aws.apigatewayv2.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateResponse
  ): zio.aws.apigatewayv2.model.GetModelTemplateResponse.ReadOnly = new Wrapper(
    impl
  )
}
